#
# spec file for package python-djvulibre
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-djvulibre
Version:        0.7
Release:        2.32
Summary:        Python Support for the DjVu Image Format
License:        GPL-2.0
Group:          Development/Libraries/Python
Url:            http://jwilk.net/software/python-djvulibre
Source0:        http://pypi.python.org/packages/source/p/python-djvulibre/%{name}-%{version}.tar.gz
Source1:        http://pypi.python.org/packages/source/p/python-djvulibre/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  graphviz
BuildRequires:  graphviz-gnome
BuildRequires:  pkg-config
BuildRequires:  python-Cython >= 0.19
BuildRequires:  python-Sphinx
BuildRequires:  python-devel >= 2.6
BuildRequires:  python-setuptools
BuildRequires:  pkgconfig(ddjvuapi) >= 3.5.21
# Required for tests.
BuildRequires:  djvulibre
BuildRequires:  python-nose
Requires:       djvulibre >= 3.5.21
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
python-djvulibre is a set of Python bindings for the DjVuLibre library,
an open source implementation of DjVu.

%package doc
Summary:        Python Support for the DjVu Image Format (Documentation)
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
python-djvulibre is a set of Python bindings for the DjVuLibre library,
an open source implementation of DjVu.

This package contains technical documentation.

%prep
%setup -q
chmod -x examples/*

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
python setup.py build
python setup.py build_sphinx

%install
python setup.py install \
    --root=%{buildroot} \
    --prefix=%{_prefix}
install -dm 0755 %{buildroot}%{_defaultdocdir}/%{name}-doc/_images/
install -dm 0755 %{buildroot}%{_defaultdocdir}/%{name}-doc/_static/
install -m 0644 build/sphinx/html/{*.html,*.js} \
    %{buildroot}%{_defaultdocdir}/%{name}-doc/
install -m 0644 build/sphinx/html/_images/* \
    %{buildroot}%{_defaultdocdir}/%{name}-doc/_images/
install -m 0644 build/sphinx/html/_static/* \
    %{buildroot}%{_defaultdocdir}/%{name}-doc/_static/

%check
cd tests/
ln -sf %{buildroot}%{python_sitearch}/djvu/ djvu
python -m nose --verbose

%files
%defattr(-,root,root,-)
%doc doc/{changelog,COPYING,credits.txt} examples/
%{python_sitearch}/*

%files doc
%defattr(-,root,root,-)
%doc %{_defaultdocdir}/%{name}-doc/

%changelog
* Mon Aug 31 2015 lazy.kent@opensuse.org
- Update to 0.7.
  * Make Expression.from_string() accept both Unicode and byte
    strings.
  * Implement __unicode__() for expressions.
  * Implement __float__() for integer expressions.
  * Be more liberal about object types that can be passed to
    escape_unicode.
  * Fix the long(<intexpr>) return type with Cython 0.23 and Python
  * 2.6.
  * Improve setup.py:
    + Put files that vary with Python version (*.c, config.pxi)
    into a version-specific temporary directory. With this change,
    it's possible to build against multiple Python versions in
    parallel.
  * Update BibTeX URL in the documentation.
  * Improve the test suite.
* Sat Aug 15 2015 lazy.kent@opensuse.org
- Update to 0.6.1.
  * Fix the DjVuLibre version check.
  * Add “const” to variable declarations and function prototypes.
  * Optimize S-expression input/output.
  * Require Cython >= 0.19, or Cython >= 0.20 for Python 3.
    + Remove work-arounds for older versions.
  * Don't pass -Wno-uninitialized to the compiler (modern versions
    of Cython don't generate code that would trigger this warning).
  * Require pkg-config for building on POSIX systems.
- Changes in 0.6.
  * Fix build failure with Cython 0.23.
  * Document which software if required to build the package.
  * Require DjVuLibre >= 3.5.21:
    + Add version check to the setup script.
    + Remove work-arounds for older versions.
    + Remove documentation warnings about older versions.
  * Remove the DjVuLibreBug class.
  * Improve the test suite.
- Changes in 0.5.
  * Make print_into() raise exceptions properly instead of just
    printing them on stderr.
  * Make it possible to print S-expressions into file-like objects
    created by codecs.open().
  * Make djvu.sexpr.__version__ a byte string in Python 2.X.
  * Don't include DjVu file format version in
    djvu.decode.__version__. This information is more conveniently
    available in djvu.decode.DDJVU_VERSION.
  * Make S-expression input/output methods reentrant (DjVuLibre >=
    3.5.26 is required for this feature).
  * Improve error handling.
  * Improve the test suite.
- Changes in 0.4.1.
  * Exclude djvu/config.pxi from the source tarball.
- Changes in 0.4.
  * Drop support for Python 2.5.
  * Add the lvalue attribute to expressions.
  * Use the lvalue in __repr__().
  * Make Symbol objects comparable using “<” and other inequality
    operators.
  * Make it possible to disable octal-escaping of non-ASCII Unicode
    characters when printing expressions into a file.
  * Stop using sphinx.ext.intersphinx.
  * Make djvu.decode.__version__ a byte string in Python 2.X.
  * Improve the test suite.
* Sun Nov 16 2014 lazy.kent@opensuse.org
- Add runtime dependency: djvulibre.
* Thu Nov 13 2014 lazy.kent@opensuse.org
- Update to 0.3.10.
  * Improve error handling in examples.
  * Improve the test suite:
    + When running external programs, don't reset environment
    completely, but only set LC_ALL=C.
    + Skip more tests (instead of making them fail) when they are
    run in an unsuitable environment.
    + Correctly detect ASCII locale encoding on FreeBSD (and
    possibly other non-GNU systems).
    + Don't hard-code libc error messages.
    + Fix test_bad_io failures with Cython ≥ 0.21.
  * Improve setup.py:
    + Make it possible to build the package natively on Windows.
  * Use HTTPS URLs when they are available, in documentation and
    code.
- Run tests. BuildRequires: djvulibre, python-nose.
- Add the source GPG signature and a keyring.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Apr 23 2012 lazy.kent@opensuse.org
- Corrected license: GPL-2.0 only (bnc#758438).
* Tue Mar 20 2012 lazy.kent@opensuse.org
- Update to 0.3.9.
  * Ensure that all S-expression output is 7-bit.
    This is work-around for deb#664626.
* Mon Mar 19 2012 lazy.kent@opensuse.org
- Update to 0.3.8.
  * Ensure that S-expression input/output functions are always
    initialized.
    This is work-around for deb#664442.
* Wed Mar 14 2012 lazy.kent@opensuse.org
- Update to 0.3.7.
  * Use floor division operator instead of relying on "classic"
    division semantics.
* Mon Mar 12 2012 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of GPL-2.0 (i.e. only) licenses in the package
* Tue Mar  6 2012 lazy.kent@opensuse.org
- Update to 0.3.6.
  * Fix compatibility with Python 2.5 (broken since 0.3.0).
* Sun Feb 19 2012 lazy.kent@opensuse.org
- Update to 0.3.5.
  * Compilation improvement.
- Remove executable bit from examples.
* Sat Oct 22 2011 lazy.kent@opensuse.org
- Update to 0.3.4.
  * Fix compatibility with Python 3.X (broken in 0.3.3).
  * Update various external documentation URLs.
- Build requires python-distribute instead of python-setuptools.
- Build doc package. Build requires python-sphinx, graphviz and
  graphviz-gnome.
* Fri Sep  9 2011 lazy.kent@opensuse.org
- Fixed build dependencies (cython -> Cython).
- Corrected License tag.
- Use full URL as a source.
* Wed Apr 13 2011 lazy.kent@opensuse.org
- Update to 0.3.3.
  * Fix test suite compatibility with Python 3.
* Sat Nov 20 2010 lazy.kent.suse@gmail.com
- Update to 0.3.1.
  * Fix encoding issues with djvu.decode.ErrorMessage.
* Fri Oct 29 2010 lazy.kent.suse@gmail.com
- Update to 0.3.0.
  * Add support for Python 3.
- BuildRequires python-setuptools.
* Sat Jun 26 2010 lazy.kent.suse@gmail.com
- Update to 0.1.18.
  * Fix handling of non-ASCII metadata.
* Tue Apr  6 2010 lazy.kent.suse@gmail.com
- Initial package created - 0.1.17.
